# Generated by roxygen2: do not edit by hand

S3method(drawDetails,splitText)
export(add_summary)
export(annotate_figure)
export(as_ggplot)
export(background_image)
export(bgcolor)
export(border)
export(change_palette)
export(clean_theme)
export(colnames_style)
export(color_palette)
export(compare_means)
export(desc_statby)
export(facet)
export(fill_palette)
export(font)
export(geom_exec)
export(get_legend)
export(get_palette)
export(ggadd)
export(ggarrange)
export(ggballoonplot)
export(ggbarplot)
export(ggboxplot)
export(ggdensity)
export(ggdotchart)
export(ggdotplot)
export(ggecdf)
export(ggerrorplot)
export(ggexport)
export(gghistogram)
export(ggline)
export(ggmaplot)
export(ggpaired)
export(ggpar)
export(ggparagraph)
export(ggpie)
export(ggqqplot)
export(ggscatter)
export(ggscatterhist)
export(ggstripchart)
export(ggtext)
export(ggtexttable)
export(ggviolin)
export(gradient_color)
export(gradient_fill)
export(grids)
export(labs_pubr)
export(mean_ci)
export(mean_range)
export(mean_sd)
export(mean_se_)
export(median_iqr)
export(median_mad)
export(median_range)
export(rotate)
export(rotate_x_text)
export(rotate_y_text)
export(rownames_style)
export(rremove)
export(set_palette)
export(show_line_types)
export(show_point_shapes)
export(stat_chull)
export(stat_compare_means)
export(stat_conf_ellipse)
export(stat_cor)
export(stat_mean)
export(stat_stars)
export(table_cell_bg)
export(table_cell_font)
export(tbody_style)
export(text_grob)
export(theme_classic2)
export(theme_cleveland)
export(theme_pubclean)
export(theme_pubr)
export(theme_transparent)
export(ttheme)
export(xscale)
export(yscale)
import(ggplot2)
importFrom(dplyr,arrange_)
importFrom(dplyr,do)
importFrom(dplyr,everything)
importFrom(dplyr,group_by)
importFrom(dplyr,group_by_)
importFrom(dplyr,mutate)
importFrom(dplyr,summarise)
importFrom(grid,drawDetails)
importFrom(magrittr,"%>%")
